"""Top-level package for simplereader."""

__author__ = """gigahanma"""
__email__ = 'random@example.com'
__version__ = '0.0.7'
from .simplereader import *


